@@ -1,4 +1,3 @@
-from easydata.parsers.bool import *  # noqa: F401 F403
 from easydata.parsers.choice import *  # noqa: F401 F403
 from easydata.parsers.clause import *  # noqa: F401 F403
 from easydata.parsers.data import *  # noqa: F401 F403
@@ -6,6 +5,7 @@ from easydata.parsers.desc import *  # noqa: F401 F403
 from easydata.parsers.dict import *  # noqa: F401 F403
 from easydata.parsers.drop import *  # noqa: F401 F403
 from easydata.parsers.email import *  # noqa: F401 F403
+from easydata.parsers.has import *  # noqa: F401 F403
 from easydata.parsers.list import *  # noqa: F401 F403
 from easydata.parsers.math import *  # noqa: F401 F403
 from easydata.parsers.misc import *  # noqa: F401 F403
